@@ -29,7 +29,14 @@ flags = [
 '-x',
 'c++',
 
+# workaround for https://github.com/Valloric/YouCompleteMe/issues/303
+# also see https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=800618
+'-isystem',
+'/usr/lib/ycmd/clang_includes/',
+
 '-I%s/include' % basedir,
+'-I%s/test/include' % basedir,
+'-I%s/src' % basedir,
 
 # libosmium include dirs
 '-I%s/../libosmium/include' % basedir,
