@@ -30,16 +30,19 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include "cmd.hpp"
 #include "exception.hpp"
 
-po::options_description Command::add_common_options() {
+po::options_description Command::add_common_options(bool with_progress) {
     po::options_description options("COMMON OPTIONS");
 
-    options.add_options()
+    auto opts = options.add_options()
     ("help,h", "Show usage help")
-    ("progress", "Display progress bar")
-    ("no-progress", "Suppress display of progress bar")
     ("verbose,v", "Set verbose mode")
     ;
 
+    if (with_progress) {
+        opts("progress", "Display progress bar")
+            ("no-progress", "Suppress display of progress bar");
+    }
+
     return options;
 }
 
@@ -71,7 +74,7 @@ void Command::setup_progress(const boost::program_options::variables_map& vm) {
     }
 }
 
-void Command::setup_object_type_nrwc(const boost::program_options::variables_map& vm) {
+void Command::setup_object_type_nwrc(const boost::program_options::variables_map& vm) {
     if (vm.count("object-type")) {
         m_osm_entity_bits = osmium::osm_entity_bits::nothing;
         for (const auto& t : vm["object-type"].as<std::vector<std::string>>()) {
@@ -92,7 +95,7 @@ void Command::setup_object_type_nrwc(const boost::program_options::variables_map
     }
 }
 
-void Command::setup_object_type_nrw(const boost::program_options::variables_map& vm) {
+void Command::setup_object_type_nwr(const boost::program_options::variables_map& vm) {
     if (vm.count("object-type")) {
         m_osm_entity_bits = osmium::osm_entity_bits::nothing;
         for (const auto& t : vm["object-type"].as<std::vector<std::string>>()) {
