@@ -23,14 +23,14 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <cstddef>
 #include <fstream>
 #include <iostream>
-#include <map>
-#include <set>
+#include <stdexcept>
 #include <string>
 #include <utility>
 #include <vector>
 
 #include <boost/program_options.hpp>
 
+#include <osmium/index/relations_map.hpp>
 #include <osmium/io/header.hpp>
 #include <osmium/io/reader.hpp>
 #include <osmium/io/writer.hpp>
@@ -48,7 +48,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 void CommandGetId::parse_and_add_id(const std::string& s) {
     auto p = osmium::string_to_object_id(s.c_str(), osmium::osm_entity_bits::nwr, m_default_item_type);
     if (p.second < 0) {
-        throw std::runtime_error("osmium-getid does not work with negative IDs");
+        throw std::runtime_error{"osmium-getid does not work with negative IDs"};
     }
     m_ids(p.first).set(p.second);
 }
@@ -56,7 +56,8 @@ void CommandGetId::parse_and_add_id(const std::string& s) {
 void CommandGetId::read_id_file(std::istream& stream) {
     m_vout << "Reading ID file...\n";
     for (std::string line; std::getline(stream, line); ) {
-        auto pos = line.find_first_of(" #");
+        strip_whitespace(line);
+        const auto pos = line.find_first_of(" #");
         if (pos != std::string::npos) {
             line.erase(pos);
         }
@@ -84,7 +85,8 @@ bool CommandGetId::setup(const std::vector<std::string>& arguments) {
     ("default-type", po::value<std::string>()->default_value("node"), "Default item type")
     ("id-file,i", po::value<std::vector<std::string>>(), "Read OSM IDs from text file")
     ("id-osm-file,I", po::value<std::vector<std::string>>(), "Read OSM IDs from OSM file")
-    ("history,H", "Make it work with history files")
+    ("history", "Deprecated, use --with-history instead")
+    ("with-history,H", "Make it work with history files")
     ("add-referenced,r", "Recursively add referenced objects")
     ("verbose-ids", "Print all requested and missing IDs")
     ;
@@ -125,7 +127,12 @@ bool CommandGetId::setup(const std::vector<std::string>& arguments) {
         m_add_referenced_objects = true;
     }
 
+    if (vm.count("with-history")) {
+        m_work_with_history = true;
+    }
+
     if (vm.count("history")) {
+        warning("The --history option is deprecated. Use --with-history instead.\n");
         m_work_with_history = true;
     }
 
@@ -275,25 +282,24 @@ void CommandGetId::read_id_osm_file(const std::string& file_name) {
     reader.close();
 }
 
-void CommandGetId::mark_rel_ids(const std::multimap<osmium::object_id_type, osmium::object_id_type>& rel_in_rel, osmium::object_id_type id) {
-    auto range = rel_in_rel.equal_range(id);
-    for (auto it = range.first; it != range.second; ++it) {
-        if (m_ids(osmium::item_type::relation).check_and_set(it->second)) {
-            mark_rel_ids(rel_in_rel, it->second);
+void CommandGetId::mark_rel_ids(const osmium::index::RelationsMapIndex& rel_in_rel, osmium::object_id_type parent_id) {
+    rel_in_rel.for_each(parent_id, [&](osmium::unsigned_object_id_type member_id) {
+        if (m_ids(osmium::item_type::relation).check_and_set(member_id)) {
+            mark_rel_ids(rel_in_rel, member_id);
         }
-    }
+    });
 }
 
 bool CommandGetId::find_relations_in_relations() {
     m_vout << "  Reading input file to find relations in relations...\n";
-    std::multimap<osmium::object_id_type, osmium::object_id_type> rel_in_rel;
+    osmium::index::RelationsMapStash stash;
 
     osmium::io::Reader reader{m_input_file, osmium::osm_entity_bits::relation};
     while (osmium::memory::Buffer buffer = reader.read()) {
         for (const auto& relation : buffer.select<osmium::Relation>()) {
             for (const auto& member : relation.members()) {
                 if (member.type() == osmium::item_type::relation) {
-                    rel_in_rel.emplace(relation.id(), member.ref());
+                    stash.add(member.ref(), relation.id());
                 } else if (m_ids(osmium::item_type::relation).get(relation.positive_id())) {
                     if (member.type() == osmium::item_type::node) {
                         m_ids(osmium::item_type::node).set(member.positive_ref());
@@ -306,10 +312,11 @@ bool CommandGetId::find_relations_in_relations() {
     }
     reader.close();
 
-    if (rel_in_rel.empty()) {
+    if (stash.empty()) {
         return false;
     }
 
+    const auto rel_in_rel = stash.build_parent_to_member_index();
     for (const osmium::unsigned_object_id_type id : m_ids(osmium::item_type::relation)) {
         mark_rel_ids(rel_in_rel, id);
     }
@@ -353,12 +360,19 @@ void CommandGetId::find_nodes_in_ways() {
 
 void CommandGetId::find_referenced_objects() {
     m_vout << "Following references...\n";
+
+    // If there are any relations we are looking for, we need to run
+    // find_relations_in_relations() to get the member IDs of all types.
     bool todo = !m_ids(osmium::item_type::relation).empty();
     if (todo) {
         todo = find_relations_in_relations();
     }
 
     if (todo) {
+        // If find_relations_in_relations() returned true, it means it found
+        // relation members that were not in the original relations ID list.
+        // This means we need to run find_nodes_and_ways_in_relations() to
+        // make sure we have all node and way members of those relations, too.
         find_nodes_and_ways_in_relations();
     }
 
@@ -382,7 +396,7 @@ bool CommandGetId::run() {
 
     osmium::io::Writer writer{m_output_file, header, m_output_overwrite, m_fsync};
 
-    m_vout << "Copying from source to output file...\n";
+    m_vout << "Copying matching objects to output file...\n";
     osmium::ProgressBar progress_bar{reader.file_size(), display_progress()};
     while (osmium::memory::Buffer buffer = reader.read()) {
         progress_bar.update(reader.offset());
