@@ -23,19 +23,24 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <map>
-#include <set>
+#include <cstddef>
+#include <iosfwd>
 #include <string>
 #include <vector>
 
 #include <osmium/fwd.hpp>
 #include <osmium/index/id_set.hpp>
+#include <osmium/index/nwr_array.hpp>
 #include <osmium/osm/entity_bits.hpp>
 #include <osmium/osm/item_type.hpp>
 #include <osmium/osm/types.hpp>
 
 #include "cmd.hpp" // IWYU pragma: export
 
+namespace osmium { namespace index {
+    class RelationsMapIndex;
+}}
+
 class CommandGetId : public Command, public with_single_osm_input, public with_osm_output {
 
     osmium::item_type m_default_item_type = osmium::item_type::node;
@@ -44,7 +49,7 @@ class CommandGetId : public Command, public with_single_osm_input, public with_o
     bool m_work_with_history = false;
     bool m_verbose_ids = false;
 
-    osmium::index::NWRIdSet<osmium::index::IdSetDense> m_ids;
+    osmium::nwr_array<osmium::index::IdSetDense<osmium::unsigned_object_id_type>> m_ids;
 
     void parse_and_add_id(const std::string& s);
 
@@ -60,7 +65,7 @@ class CommandGetId : public Command, public with_single_osm_input, public with_o
     void add_nodes(const osmium::Way& way);
     void add_members(const osmium::Relation& relation);
 
-    void mark_rel_ids(const std::multimap<osmium::object_id_type, osmium::object_id_type>& rel_in_rel, osmium::object_id_type id);
+    void mark_rel_ids(const osmium::index::RelationsMapIndex& rel_in_rel, osmium::object_id_type parent_id);
     bool find_relations_in_relations();
     void find_nodes_and_ways_in_relations();
     void find_nodes_in_ways();
