@@ -26,14 +26,13 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
-#include <osmium/io/header.hpp>
-
 #include "cmd.hpp" // IWYU pragma: export
 
 class CommandShow : public Command, public with_single_osm_input {
 
     std::string m_output_format{"debug,color=true"};
     std::string m_pager;
+    bool m_color_output;
 
     void setup_pager_from_env() noexcept;
 
@@ -43,6 +42,8 @@ public:
 
     bool setup(const std::vector<std::string>& arguments) override final;
 
+    void show_arguments() override final;
+
     bool run() override final;
 
     const char* name() const noexcept override final {
