@@ -34,7 +34,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/memory/buffer.hpp>
 #include <osmium/osm/location.hpp>
 
-#include "error.hpp"
+#include "../exception.hpp"
 #include "geojson_file_parser.hpp"
 
 std::string get_value_as_string(const rapidjson::Value& object, const char* key) {
@@ -129,12 +129,14 @@ std::size_t parse_multipolygon_array(const rapidjson::Value& value, osmium::memo
         throw config_error{"Multipolygon must contain at least one polygon array."};
     }
 
-    for (const auto& polygon : array) {
-        if (!polygon.IsArray()) {
-            throw config_error{"Polygon must be an array."};
-        }
+    {
         osmium::builder::AreaBuilder builder{buffer};
-        parse_rings(polygon, builder);
+        for (const auto& polygon : array) {
+            if (!polygon.IsArray()) {
+                throw config_error{"Polygon must be an array."};
+            }
+            parse_rings(polygon, builder);
+        }
     }
 
     return buffer.commit();
@@ -190,8 +192,8 @@ std::size_t GeoJSONFileParser::operator()() {
     if (geometry_type.empty()) {
         error("Missing 'geometry.type'.");
     }
-    if (geometry_type != "Polygon" && geometry_type != "Multipolygon") {
-        error("Expected 'geometry.type' value to be 'Polygon' or 'Multipolygon'.");
+    if (geometry_type != "Polygon" && geometry_type != "MultiPolygon") {
+        error("Expected 'geometry.type' value to be 'Polygon' or 'MultiPolygon'.");
     }
 
     const auto json_coordinates = json_geometry->value.FindMember("coordinates");
