@@ -24,6 +24,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/util/file.hpp>
 
 #include "strategy_complete_ways.hpp"
+#include "../util.hpp"
 
 namespace strategy_complete_ways {
 
@@ -36,12 +37,16 @@ namespace strategy_complete_ways {
         });
     }
 
-    Strategy::Strategy(const std::vector<std::unique_ptr<Extract>>& extracts, const osmium::util::Options& /*options*/) :
+    Strategy::Strategy(const std::vector<std::unique_ptr<Extract>>& extracts, const osmium::util::Options& options) :
         ExtractStrategy() {
         m_extracts.reserve(extracts.size());
         for (const auto& extract : extracts) {
             m_extracts.emplace_back(*extract);
         }
+
+        for (const auto& option : options) {
+            warning(std::string{"Ignoring unknown option '"} + option.first + "' for 'complete_ways' strategy.\n");
+        }
     }
 
     const char* Strategy::name() const noexcept {
@@ -148,7 +153,7 @@ namespace strategy_complete_ways {
 
     void Strategy::run(osmium::util::VerboseOutput& vout, bool display_progress, const osmium::io::File& input_file) {
         vout << "Running 'complete_ways' strategy in two passes...\n";
-        const size_t file_size = osmium::util::file_size(input_file.filename());
+        const std::size_t file_size = osmium::util::file_size(input_file.filename());
         osmium::ProgressBar progress_bar{file_size * 2, display_progress};
 
         vout << "First pass...\n";
@@ -157,7 +162,7 @@ namespace strategy_complete_ways {
         progress_bar.file_done(file_size);
 
         // recursively get parents of all relations that are in an extract
-        auto relations_map = pass1.relations_map_stash().build_index();
+        const auto relations_map = pass1.relations_map_stash().build_member_to_parent_index();
         for (auto& e : m_extracts) {
             for (osmium::unsigned_object_id_type id : e.relation_ids) {
                 e.add_relation_parents(id, relations_map);
