@@ -159,7 +159,7 @@ namespace strategy_complete_ways_with_history {
 
     void Strategy::run(osmium::util::VerboseOutput& vout, bool display_progress, const osmium::io::File& input_file) {
         vout << "Running 'complete_ways' strategy in two passes...\n";
-        const size_t file_size = osmium::util::file_size(input_file.filename());
+        const std::size_t file_size = osmium::util::file_size(input_file.filename());
         osmium::ProgressBar progress_bar{file_size * 2, display_progress};
 
         vout << "First pass...\n";
@@ -169,7 +169,7 @@ namespace strategy_complete_ways_with_history {
         pass1.add_extra_nodes();
 
         // recursively get parents of all relations that are in an extract
-        auto relations_map = pass1.relations_map_stash().build_index();
+        const auto relations_map = pass1.relations_map_stash().build_member_to_parent_index();
         for (auto& e : m_extracts) {
             for (osmium::unsigned_object_id_type id : e.relation_ids) {
                 e.add_relation_parents(id, relations_map);
